var react = require('react');
var lal = require('lal');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var _process$env = process.env,
    mainKey = _process$env.REACT_APP_API_MAIN_KEY,
    mainURL = _process$env.REACT_APP_API_MAIN_URL;
function useRequest(props) {
  var _uno = lal.uno(props),
      apiKey = _uno.apiKey,
      baseURL = _uno.baseURL,
      debug = _uno.debug,
      baseState = _uno.baseState,
      _uno$onError = _uno.onError,
      _onError = _uno$onError === void 0 ? function () {} : _uno$onError,
      _uno$onSuccess = _uno.onSuccess,
      _onSuccess = _uno$onSuccess === void 0 ? function () {} : _uno$onSuccess,
      params = _uno.params,
      mono = _uno.mono,
      url = _uno.url,
      rest = _objectWithoutPropertiesLoose(_uno, ["apiKey", "baseURL", "debug", "baseState", "onError", "onSuccess", "params", "mono", "url"]);

  var stateDefault = baseState && baseState.basePesist ? baseState : null;

  var _useState = react.useState(stateDefault),
      error = _useState[0],
      setError = _useState[1];

  var _useState2 = react.useState(null),
      response = _useState2[0],
      setResponse = _useState2[1];

  var resetState = function resetState(_ref) {
    var keepContent = _ref.keepContent,
        keepError = _ref.keepError;
    if (!keepContent) setResponse(stateDefault);
    if (!keepError) setError(null);
  };

  var resArr = ['error', 'success'];

  var execute = function execute(res, updateState, onFinish, clear, pass) {
    var resObj = pass ? _extends({}, baseState, res) : res;
    if (debug) console.log('hangers useAPI', resArr[pass], resObj);
    updateState(resObj);
    clear(pass ? null : stateDefault);
    onFinish(resObj);
  };

  var queryObj = _extends({
    apiKey: apiKey !== undefined ? apiKey : mainKey
  }, params);

  var request = react.useCallback(function () {
    return lal.api(_extends({
      baseURL: baseURL || mainURL,
      debug: debug,
      onError: function onError(err) {
        return execute(err, setError, _onError, setResponse, 0);
      },
      onSuccess: function onSuccess(res) {
        return execute(res, setResponse, _onSuccess, setError, 1);
      },
      params: queryObj,
      url: mono || url
    }, rest)).then(function (res) {
      return lal.log(undefined, {
        hangersDebug: 'success',
        res: res
      }, res.debug);
    })["catch"](function (err) {
      return lal.log(undefined, {
        hangersDebug: 'error',
        err: err
      }, err.debug);
    });
  });
  return {
    request: request,
    response: response,
    setResponse: setResponse,
    error: error,
    setError: setError,
    resetState: resetState
  };
}

function useThrottle(toDo, status, setStatus, watch, delay, debug, holdDelay) {
  if (toDo === void 0) {
    toDo = function toDo() {};
  }

  if (delay === void 0) {
    delay = 0;
  }

  if (holdDelay === void 0) {
    holdDelay = false;
  }

  var _useState = react.useState(watch),
      watchStore = _useState[0],
      updateWatch = _useState[1];

  react.useEffect(function () {
    var timer = setTimeout(function () {
      if (debug && !status) console.log('hangers useThrottle timer');

      if (!status) {
        if (debug) console.log('useThrottle switch');
        setStatus(1);
        toDo();
      }
    }, holdDelay ? 0 : delay);
    return function () {
      return clearTimeout(timer);
    };
  }, [status]);
  react.useEffect(function () {
    if (watch !== watchStore && status > 1) {
      if (debug) console.log('useThrottle watch trigger');
      updateWatch(watch);
      setStatus(0);
    }
  }, [status, watch, watchStore]);
  return {
    watchStore: watchStore,
    updateWatch: updateWatch
  };
}

function useRelay(props) {
  var _uno = lal.uno(props),
      debug = _uno.debug,
      delay = _uno.delay,
      _uno$onError = _uno.onError,
      _onError = _uno$onError === void 0 ? function () {} : _uno$onError,
      _uno$onSuccess = _uno.onSuccess,
      _onSuccess = _uno$onSuccess === void 0 ? function () {} : _uno$onSuccess,
      paused = _uno.paused,
      mono = _uno.mono,
      retry = _uno.retry,
      slowOnError = _uno.slowOnError,
      url = _uno.url,
      watch = _uno.watch,
      rest = _objectWithoutPropertiesLoose(_uno, ["debug", "delay", "onError", "onSuccess", "paused", "mono", "retry", "slowOnError", "url", "watch"]);

  var _useState = react.useState(paused ? -1 : 0),
      status = _useState[0],
      setStatus = _useState[1];

  var execute = function execute(res, step, onFinish) {
    onFinish(res);
    setStatus(step);
  };

  var _useRequest = useRequest(_extends({
    debug: debug,
    onError: function onError(res) {
      return execute(res, retry ? 0 : 3, _onError);
    },
    onSuccess: function onSuccess(res) {
      return execute(res, 2, _onSuccess);
    },
    url: mono || url
  }, rest)),
      error = _useRequest.error,
      request = _useRequest.request,
      hooks = _objectWithoutPropertiesLoose(_useRequest, ["error", "request"]);

  var _useThrottle = useThrottle(request, status, setStatus, watch, delay, debug, slowOnError && !error);

  return _extends({
    hold: !status || status === 1,
    request: request,
    status: status,
    setStatus: setStatus
  }, hooks);
}

function useTimeout(toDo, wait) {
  if (toDo === void 0) {
    toDo = function toDo() {};
  }

  if (wait === void 0) {
    wait = 3000;
  }

  react.useEffect(function () {
    var timer = setTimeout(function () {
      toDo();
    }, wait);
    return function () {
      return clearTimeout(timer);
    };
  });
}

function useYap(props) {
  var _useState = react.useState(false),
      status = _useState[0],
      setStatus = _useState[1];

  react.useEffect(function () {
    console.log('testing status', status);
  }, [status]);
  return [status, setStatus];
}

exports.useRelay = useRelay;
exports.useRequest = useRequest;
exports.useTimeout = useTimeout;
exports.useYap = useYap;
//# sourceMappingURL=index.js.map
